# -*- coding: utf-8 -*-

import importlib
import logging

import colander
import IPy
from pyramid.httpexceptions import HTTPNotFound
from pyramid.settings import aslist
from pyramid.view import view_config

from .. import __version__ as version

log = logging.getLogger(__name__)


class ReturnMonitoring(colander.MappingSchema):
    pyramid_includes = colander.MappingSchema(typ=colander.Mapping("preserve"))
    sequoia_export = colander.MappingSchema(typ=colander.Mapping("preserve"))

    sequoia_base3 = colander.SchemaNode(
        colander.String(), name="sequoia.base3", missing=colander.drop
    )


@view_config(route_name="monitoring", renderer="json", return_schema=ReturnMonitoring)
def monitoring(request):
    conf = request.registry.settings

    remote_addr = request.client_addr
    authorized_ips = conf.get("sequoia.monitoring.ips", "127.0.0.1 ::1").split()
    for ip in authorized_ips:
        try:
            ip = IPy.IP(ip)
        except ValueError:
            log.warning(
                '"%s" is not a valid IP address, '
                "please fix settings `sequoia.monitoring.ips`"
            )
            continue

        if remote_addr in ip:
            break
    else:
        log.warning(
            "IP %s try to get the monitoring view but access not "
            "granted, current range(s): %s" % (remote_addr, " ".join(authorized_ips))
        )
        raise HTTPNotFound

    pyramid_includes = aslist(conf["pyramid.includes"], flatten=False)
    sequoia_export = aslist(conf["sequoia.export"], flatten=False)

    res = {
        "pyramid_includes": {},
        "sequoia_export": {},
    }

    for api in pyramid_includes:
        if api.startswith("#"):
            continue
        mod = importlib.import_module(api)
        res["pyramid_includes"][api] = getattr(mod, "__version__", "Unknown")

    for api in sequoia_export:
        if api.startswith("#"):
            continue
        mod = importlib.import_module(api)
        res["sequoia_export"][api] = getattr(mod, "__version__", "Unknown")

    res["sequoia.base3"] = version

    return res
