"""
The Root Context

used when a view did not declare it's own context.
"""

from pyramid.decorator import reify
from pyramid.security import (
    ALL_PERMISSIONS,
    NO_PERMISSION_REQUIRED,
    Allow,
    Authenticated,
    Everyone,
)


class DefaultContext(object):
    """
    A default request context.
    """

    default_acl = [
        (Allow, Everyone, NO_PERMISSION_REQUIRED),
        (
            Allow,
            Authenticated,
            ["authenticated", "offers:read", "simplehosting:old", "hosting:old"],
        ),
        (Allow, "god", ALL_PERMISSIONS),
        # the refresh token ACL
        (Allow, "refresh_token", "refresh_token"),
        (Allow, "internal", ["internal", "authenticated"]),
        (Allow, "authorized_ip", ["authorized_ip", "prometheus:metric:read"]),
    ]

    def __init__(self, request):
        self.request = request
        self.return_schema = None
        self.http_vary = None
        self._acl = DefaultContext.default_acl[:]

    @reify
    def authenticated_user(self):
        """
        return the authenticated user

        :return: authenticated user
        :rtype: dict
        """
        contact = self.request.authenticated_userid

        if not contact:
            return None

        return contact

    @reify
    def __acl__(self):
        return self._acl

    def append_acl(self, role, rights):
        self._acl.append((Allow, role, rights))
