# -*- coding: utf-8 -*-
""" Bitmask for SQLAlchemy """


class Bitmask(set):
    """Handle bitmask fields"""

    _flags = {}

    @classmethod
    def get_bitmask(cls, flag):
        assert flag in cls._flags, "%s not in %s" % (flag, cls._flags)
        return cls._flags[flag]

    @classmethod
    def match(cls, flag, bitmask):
        if bitmask is None:
            bitmask = 0
        flagmask = cls.get_bitmask(flag)
        return flagmask & bitmask == flagmask

    def __init__(self, model, bitfield):
        self._model = model
        self._bitfield = bitfield
        bitmask = getattr(model, bitfield, 0)
        flags = [flag for flag in self._flags if self.match(flag, bitmask)]
        super(Bitmask, self).__init__(set(flags or []))

    @property
    def bitmask(self):
        bitmask = 0
        for flag in self:
            bitmask |= self.get_bitmask(flag)
        return bitmask

    def append(self, flag):
        """Append a flag to the bitmask, and update the model bitfield"""
        self.add(flag)
        setattr(self._model, self._bitfield, self.bitmask)

    def remove(self, flag):
        self.discard(flag)
        setattr(self._model, self._bitfield, self.bitmask)

    def __repr__(self):
        return "<%s %s [%i]>" % (self.__class__.__name__, ",".join(self), self.bitmask)
