"""
Internationalization
====================


"""

import translationstring

gettext = translationstring.TranslationStringFactory("sequoia.base3")

#: Mapping of language codes send by browsers to supported dialects.

# last known spec:
# From Thomas Kuiper - https://phabricator.corp.gandi.net/T3137
# Expected behavior:
# zh-HK: Traditional Chinese (zh-hant)
# zh-TW: Traditional Chinese (zh-hant)
# All other zh* (unless there's a zh*Hant language tag):
# Simplified Chinese (zh-hans)

# Note: the mapping is ordered
LANGUAGES = dict(
    (
        ("en-au", "en"),
        ("en-bz", "en"),
        ("en-ca", "en"),
        ("en-cb", "en"),
        ("en-gb", "en"),
        ("en-ie", "en"),
        ("en-jm", "en"),
        ("en-nz", "en"),
        ("en-ph", "en"),
        ("en-tt", "en"),
        ("en-us", "en"),
        ("en-za", "en"),
        ("en-zw", "en"),
        ("fr-fr", "fr"),
        ("fr-be", "fr"),
        ("fr-ca", "fr"),
        ("fr-ch", "fr"),
        ("fr-lu", "fr"),
        ("fr-mc", "fr"),
        ("es-ar", "es"),
        ("es-bo", "es"),
        ("es-cl", "es"),
        ("es-co", "es"),
        ("es-cr", "es"),
        ("es-do", "es"),
        ("es-ec", "es"),
        ("es-es", "es"),
        ("es-es", "es"),
        ("es-gt", "es"),
        ("es-hn", "es"),
        ("es-mx", "es"),
        ("es-ni", "es"),
        ("es-pa", "es"),
        ("es-pe", "es"),
        ("es-pr", "es"),
        ("es-py", "es"),
        ("es-sv", "es"),
        ("es-uy", "es"),
        ("es-ve", "es"),
        ("eu-es", "es"),
        ("ja-jp", "ja"),
        ("en", "en"),
        ("fr", "fr"),
        ("es", "es"),
        ("ja", "ja"),
        ("ja-jp", "ja"),
        ("zh-hans", "zh_CN"),
        ("zh-cn", "zh_CN"),
        ("lzh", "zh_CN"),
        ("yue", "zh_CN"),
        ("nan", "zh_CN"),
        ("zh-mo", "zh_CN"),
        ("zh-sg", "zh_CN"),
        ("zh-min-nan", "zh_CN"),
        ("zh-my", "zh_CN"),
        ("zh-yue", "zh_CN"),
        ("zh-hant", "zh_TW"),
        ("zh-tw", "zh_TW"),
        ("zh-hk", "zh_TW"),
        # Important to be done on the last
        ("zh", "zh_CN"),
    )
)
LANGUAGE_LIST = list(LANGUAGES)


def locale_negotiator(request):
    """
    Locale negotiator base on the ``Accept-Language`` http header

    The choosen locale is the first that match the key of the
    :data:`sequoia.base3.helpers.i18n.LANGUAGES`
    dict. If no languages can be necotiate, it fallback to ``en``

    the negociator is automatically import at the start
    of the wsgi application.
    """
    lang = default = "en"
    if request.accept_language:
        lang = request.accept_language.lookup(LANGUAGE_LIST, default_tag=default)
        lang = LANGUAGES.get(lang, "en")
    return lang


def content_language(request):
    """A cornice validator that add the ``Content-Language``,
    if an ``Accept-Language`` as been sent otherwise en as the default one"""

    request.response.content_language = {
        "zh_CN": "zh-hans",
        "zh_TW": "zh-hant",
    }.get(request.locale_name, request.locale_name)
