"""Handle pagination"""
from typing import Optional

from pydantic import BaseModel

from .types import UUID
from .typing import QueryStringField


class PaginationSchema(BaseModel):
    """A Base class for collection request with pagination fields."""

    page: int = QueryStringField(default=1, gte=1)
    per_page: int = QueryStringField(default=50, gte=1)
    sort_by: str = QueryStringField(default="id")
    sharing_id: Optional[UUID] = QueryStringField(default=None)

    @property
    def limit(self) -> int:
        return self.per_page

    @property
    def offset(self) -> int:
        return (self.page - 1) * self.limit
