# flake8: noqa
from ..i18n import gettext as _

# list of errors has been stolen from
# https://raw.githubusercontent.com/orsinium-labs/pydantic-translations/master/pydantic_translations/_messages.py
# but we can't use this module which is python 3.8

PYDANTIC_ERRORS = {
    # type errors
    "byte type expected": _("byte type expected"),
    "str type expected": _("str type expected"),
    "value could not be parsed to a boolean": _(
        "value could not be parsed to a boolean"
    ),
    # value errors
    "could not parse value and unit from byte string": _(
        "could not parse value and unit from byte string"
    ),
    "invalid date format": _("invalid date format"),
    "invalid datetime format": _("invalid datetime format"),
    "invalid duration format": _("invalid duration format"),
    "Invalid JSON": _("Invalid JSON"),
    "invalid time format": _("invalid time format"),
    "value is not a valid email address": _("value is not a valid email address"),
    "value is not a valid IPv4 address": _("value is not a valid IPv4 address"),
    "value is not a valid IPv4 interface": _("value is not a valid IPv4 interface"),
    "value is not a valid IPv4 network": _("value is not a valid IPv4 network"),
    "value is not a valid IPv4 or IPv6 address": _(
        "value is not a valid IPv4 or IPv6 address"
    ),
    "value is not a valid IPv4 or IPv6 interface": _(
        "value is not a valid IPv4 or IPv6 interface"
    ),
    "value is not a valid IPv4 or IPv6 network": _(
        "value is not a valid IPv4 or IPv6 network"
    ),
    "value is not a valid IPv6 address": _("value is not a valid IPv6 address"),
    "value is not a valid IPv6 interface": _("value is not a valid IPv6 interface"),
    "value is not a valid IPv6 network": _("value is not a valid IPv6 network"),
    "type_error.arbitrary_type": _("instance of ${expected_arbitrary_type} expected"),
    "type_error.bool": _("value is not a valid boolean"),
    "type_error.callable": _("{value} is not callable"),
    "type_error.class": _("a class is expected"),
    "type_error.dataclass": _("instance of ${class_name}, tuple or dict expected"),
    "type_error.decimal": _("value is not a valid decimal"),
    "type_error.deque": _("value is not a valid deque"),
    "type_error.dict": _("value is not a valid dict"),
    "type_error.enum_instance": _("${value} is not a valid Enum instance"),
    "type_error.enum": _(
        "value is not a valid enumeration member; permitted: ${permitted}"
    ),
    "type_error.float": _("value is not a valid float"),
    "type_error.frozenset": _("value is not a valid frozenset"),
    "type_error.hashable": _("value is not a valid hashable"),
    "type_error.int_enum_instance": _("${value} is not a valid IntEnum instance"),
    "type_error.integer": _("value is not a valid integer"),
    "type_error.iterable": _("value is not a valid iterable"),
    "type_error.json": _("JSON object must be str, bytes or bytearray"),
    "type_error.list": _("value is not a valid list"),
    "type_error.none.allowed": _("value is not none"),
    "type_error.none.not_allowed": _("none is not an allowed value"),
    "type_error.not_none": _("value is not None"),
    "type_error.path": _("value is not a valid path"),
    "type_error.pyobject": _(
        "ensure this value contains valid import path or valid callable: ${error_message}"
    ),
    "type_error.sequence": _("value is not a valid sequence"),
    "type_error.set": _("value is not a valid set"),
    "type_error.subclass": _("subclass of ${expected_class} expected"),
    "type_error.tuple": _("value is not a valid tuple"),
    "type_error.uuid": _("value is not a valid uuid"),
    "value_error.any_str.max_length": _(
        "ensure this value has at most ${limit_value} characters"
    ),
    "value_error.any_str.min_length": _(
        "ensure this value has at least ${limit_value} characters"
    ),
    "value_error.color": _("value is not a valid color: ${reason}"),
    "value_error.const": _("unexpected value; permitted: ${permitted}"),
    "value_error.date.not_in_the_future": _("date is not in the future"),
    "value_error.date.not_in_the_past": _("date is not in the past"),
    "value_error.decimal.max_digits": _(
        "ensure that there are no more than ${max_digits} digits in total"
    ),
    "value_error.decimal.max_places": _(
        "ensure that there are no more than ${decimal_places} decimal places"
    ),
    "value_error.decimal.not_finite": _("value is not a valid decimal"),
    "value_error.decimal.whole_digits": _(
        "ensure that there are no more than ${whole_digits} digits before the decimal point"
    ),
    "value_error.discriminated_union.invalid_discriminator": _(
        "No match for discriminator ${discriminator_key} and value ${discriminator_value} (allowed values: ${allowed_values})"
    ),
    "value_error.discriminated_union.missing_discriminator": _(
        "Discriminator ${discriminator_key} is missing in value"
    ),
    "value_error.extra": _("extra fields not permitted"),
    "value_error.frozenset.max_items": _(
        "ensure this value has at most ${limit_value} items"
    ),
    "value_error.frozenset.min_items": _(
        "ensure this value has at least ${limit_value} items"
    ),
    "value_error.invalidbytesizeunit": _("could not interpret byte unit: ${unit}"),
    "value_error.list.max_items": _(
        "ensure this value has at most ${limit_value} items"
    ),
    "value_error.list.min_items": _(
        "ensure this value has at least ${limit_value} items"
    ),
    "value_error.list.unique_items": _("the list has duplicated items"),
    "value_error.missing": _("field required"),
    "value_error.number.not_finite_number": _("ensure this value is a finite number"),
    "value_error.number.not_ge": _(
        "ensure this value is greater than or equal to ${limit_value}"
    ),
    "value_error.number.not_gt": _("ensure this value is greater than ${limit_value}"),
    "value_error.number.not_le": _(
        "ensure this value is less than or equal to ${limit_value}"
    ),
    "value_error.number.not_lt": _("ensure this value is less than ${limit_value}"),
    "value_error.number.not_multiple": _(
        "ensure this value is a multiple of ${multiple_of}"
    ),
    "value_error.path.not_a_directory": _(
        'path "${path}" does not point to a directory'
    ),
    "value_error.path.not_a_file": _('path "${path}" does not point to a file'),
    "value_error.path.not_exists": _(
        'file or directory at path "${path}" does not exist'
    ),
    "value_error.payment_card_number.digits": _("card number is not all digits"),
    "value_error.payment_card_number.invalid_length_for_brand": _(
        "Length for a ${brand} card must be ${required_length}"
    ),
    "value_error.payment_card_number.luhn_check": _("card number is not luhn valid"),
    "value_error.regex_pattern": _("Invalid regular expression"),
    "value_error.set.max_items": _(
        "ensure this value has at most ${limit_value} items"
    ),
    "value_error.set.min_items": _(
        "ensure this value has at least ${limit_value} items"
    ),
    "value_error.str.regex": _('string does not match regex "${pattern}"'),
    "value_error.tuple.length": _(
        "wrong tuple length ${actual_length}, expected ${expected_length}"
    ),
    "value_error.url.extra": _(
        "URL invalid, extra characters found after valid URL: ${extra}"
    ),
    "value_error.url.host": (
        _("URL host invalid"),
        _("URL host invalid, top level domain required"),
    ),
    "value_error.url.port": _("URL port invalid, port cannot exceed 65535"),
    "value_error.url.scheme": (
        _("invalid or missing URL scheme"),
        _("URL scheme not permitted"),
    ),
    "value_error.url.userinfo": _("userinfo required in URL but missing"),
    "value_error.uuid.version": _("uuid version ${required_version} expected"),
}
