"""
Types used to build some model fields.
"""
import uuid

from sequoia.base3.helpers.i18n import gettext as _


class UUID(str):
    """A string that match an uuid format."""

    @classmethod
    def __get_validators__(cls):
        # one or more validators may be yielded which will be called in the
        # order to validate the input, each validator will receive as an input
        # the value returned from the previous validator
        yield cls.validate

    @classmethod
    def __modify_schema__(cls, field_schema):
        # __modify_schema__ should mutate the dict it receives in place,
        # the returned value will be ignored
        field_schema.update(
            pattern="^[A-F0-9a-f]{8}(-[A-F0-9a-f]{4}){3}-[A-F0-9a-f]{12}$",
            examples=["4a33135d-8aa3-47ba-bcfd-faa297b7fb5b"],
        )

    @classmethod
    def validate(cls, v):
        err = _("uuid format expected")
        if not isinstance(v, str):
            raise TypeError(err)

        try:
            uuid.UUID(v)
        except ValueError:
            raise ValueError(err)
        return cls(f"{v}")

    def __repr__(self):
        return f"UUID({super().__repr__()})"
