"""
Some types for pydantic.
"""
from functools import partial

from pydantic import Field
from typing_extensions import Literal

HttpLocation = Literal["path", "querystring", "body", "header"]

PATH: HttpLocation = "path"
HEADER: HttpLocation = "header"
QUERY: HttpLocation = "querystring"
BODY: HttpLocation = "body"


PathInfoField = partial(Field, location=PATH)
"""Declare field that are serialized to the path info."""
HeaderField = partial(Field, location=HEADER)
"""Declare field that are serialized in http request header."""
QueryStringField = partial(Field, location=QUERY)
"""Declare field that are serialized in the http querystring."""
PostBodyField = partial(Field, location=BODY)
"""Declare field that are serialized in the json document."""
