import datetime
import json
from decimal import Decimal

from sequoia.base3.helpers.pyramid import Request

try:
    from freezegun.api import FakeDatetime
except ImportError:
    FakeDatetime = None


def set_content_type(request: Request) -> None:
    """Set the response content type fro the request Accept header."""
    acceptable = ("application/json", "text/json", "text/plain")
    content_type = acceptable[0]
    content_types = request.accept.acceptable_offers(acceptable)
    if content_types:
        content_type = content_types[0][0]
    request.response.content_type = str(content_type)  # type: ignore


class JSONEncoder(json.JSONEncoder):
    """JSON encoder which understands decimals and datetimes"""

    _datetypes = (datetime.date, datetime.datetime)

    # During tests, we will need to serialize faked datetime
    # object generated by freezegun, handle them correctly in decoder,
    # without breaking if freezegun isn't installed
    if FakeDatetime:
        _datetypes += (FakeDatetime,)

    def default(self, obj):
        """Convert object to JSON encodable type."""
        if isinstance(obj, Decimal):
            return float(obj)
        if isinstance(obj, self._datetypes):
            return obj.strftime("%Y-%m-%dT%H:%M:%SZ")
        return super(JSONEncoder, self).default(obj)
