import ast
import logging
import os

SEQUOIA_ENVIRONMENT_VARIABLE_PREFIX = "SEQUOIA_"

log = logging.getLogger(__name__)


def patch_settings_from_env(settings):
    """Patch settings from environment variables.

    If the environment variable starts by the prefix SEQUOIA_, the
    rest of the environment variable name is considered as a setting
    key. This value of this setting from the configuration is then
    overridden by the value of the environment variable.

    Because a shell variable can not contain the '.' character, '__'
    is replaced by '.'. For instance, the `SEQUOIA_sql__password`
    environment variable corresponds to the setting `sql.password`.

    """
    for k, v in os.environ.items():
        if k.startswith(SEQUOIA_ENVIRONMENT_VARIABLE_PREFIX):
            variable = (
                k[len(SEQUOIA_ENVIRONMENT_VARIABLE_PREFIX):]  # fmt: skip
                if k.startswith(SEQUOIA_ENVIRONMENT_VARIABLE_PREFIX)
                else k
            )
            # '.' are not allowed in shell environment variable name.
            variable = variable.replace("__", ".")
            try:
                v = ast.literal_eval(v)
            except Exception:
                pass
            settings[variable] = v
            log.info("Patch setting {} with value {}".format(variable, v))
