from sequoia.base3.testing.case import ApiTestCase


class AcceptTestCase(ApiTestCase):
    app_settings = {
        "sequoia.export": "sequoia.base3.tests.api.dummy",
    }

    def test_no_accept(self):
        result = self.app.get("/mimes", status=200)
        self.assertEqual(result.content_type, "application/json")

    def test_accept_registered_view(self):
        result = self.app.get("/mimes", headers={"accept": "text/plain"}, status=200)
        self.assertEqual(result.content_type, "text/plain")

    def test_accept_registered_view_wildcard(self):
        result = self.app.get("/mimes", headers={"accept": "text/*"}, status=200)
        self.assertEqual(result.content_type, "text/plain")

    def test_accept_unregistered_view(self):
        result = self.app.get("/mimes", headers={"accept": "text/csv"}, status=200)
        self.assertEqual(result.content_type, "application/json")

    def test_accept_any(self):
        result = self.app.get("/mimes", headers={"accept": "*/*"}, status=200)
        self.assertEqual(result.content_type, "application/json")

    def test_accept_default_view(self):
        result = self.app.get(
            "/mimes", headers={"accept": "application/json"}, status=200
        )
        self.assertEqual(result.content_type, "application/json")

    def test_accept_default_view_multi(self):
        result = self.app.get(
            "/mimes", headers={"accept": "application/json, */*"}, status=200
        )
        self.assertEqual(result.content_type, "application/json")

    def test_accept_registered_view_weight(self):
        accept = "application/json;q=0.5, text/*;q=0.8"
        result = self.app.get("/mimes", headers={"accept": accept}, status=200)
        self.assertEqual(result.content_type, "text/plain")

    def test_accept_default_view_weight(self):
        accept = "text/*;q=0.2, application/json"
        result = self.app.get("/mimes", headers={"accept": accept}, status=200)
        self.assertEqual(result.content_type, "application/json")


class AcceptTestCaseWithPydantic(AcceptTestCase):
    app_settings = {
        "pyramid.includes": "sequoia.base3.helpers.pydantic",
        "sequoia.export": "sequoia.base3.tests.api.dummy_pydantic",
    }
