from unittest import TestCase

from sequoia.base3 import __version__ as base3_version
from sequoia.base3.api.monitoring import ReturnMonitoring
from sequoia.base3.testing.case import ApiTestCase


class MonitoringTestCase(ApiTestCase):
    app_settings = {
        "sequoia.export": "",
        "pyramid.includes": "",
    }

    def test_ok(self):
        result = self.app.get(
            "/monitoring", status=200, headers={"X-Forwarded-For": "127.0.0.1"}
        )
        assert result.json == {
            "pyramid_includes": {},
            "sequoia.base3": base3_version,
            "sequoia_export": {},
        }

    def test_forbidden_ip(self):
        result = self.app.get(
            "/monitoring", status=404, headers={"X-Forwarded-For": "42.13.37.24"}
        )
        assert result.json == {
            "cause": "Not Found",
            "code": 404,
            "message": "The resource could not be found.",
            "object": "HTTPNotFound",
        }


class MisConfiguredMonitoringTestCase(MonitoringTestCase):
    app_settings = {
        "sequoia.export": "",
        "pyramid.includes": "",
        "sequoia.monitoring.ips": "not_an_ip 127.0.0.1",
    }


class ColanderMonitoringTest(TestCase):
    def test_schema_valide(self):
        data = {
            "pyramid_includes": {
                "sequoia.base3": "5.0.70",
                "restela": "5.0.17",
                "sherman": "0.7",
                "sequoia.api.hosting": "5.0.81",
                "sequoia.auth.oauth2": "5.0.32",
            },
            "sequoia_export": {
                "sequoia.api.schema": "5.0.2",
                "sequoia.api.hosting": "5.0.81",
                "sequoia.api.region": "5.0.30",
            },
            "sequoia.base3": "5.0.70",
        }
        res = ReturnMonitoring().deserialize(data)
        self.assertEqual(res, data)
