import json
import os
import tempfile
from typing import Any, Iterator, Mapping

import pytest
from cornice.errors import Errors
from pyramid.testing import DummyRequest as _DummyRequest
from pyramid.testing import setUp, tearDown

CONTENT = """
[app:main]
use = egg:sequoia.base3

pyramid.default_locale_name = en

sql.dummy.url = sqlite://

"""


@pytest.fixture
def paster_file() -> Iterator[str]:
    filename = tempfile.mktemp(suffix=".ini", prefix="fake-")
    with open(filename, "w") as file_:
        file_.write(CONTENT)
    yield filename
    os.unlink(filename)


@pytest.fixture
def paster_file_with_env(params, paster_file, monkeypatch) -> Iterator[str]:
    for key, val in params["settings"].items():
        monkeypatch.setenv(key, val)
    yield paster_file


class Localizer:
    def __init__(self, translations):
        self.translations = translations

    def translate(self, msg, mapping=None):
        ret = self.translations.get(msg, msg)
        if mapping:
            ret = ret.format(**mapping)
        return ret


class DummyRequest(_DummyRequest):
    def __init__(self, *args, **kwargs):
        kwargs["errors"] = Errors()
        kwargs["validated"] = {}
        if "body" in kwargs:
            kwargs["body"] = json.dumps(kwargs["body"])

        super(DummyRequest, self).__init__(*args, **kwargs)
        self.content_type = "application/json"

    @property
    def json_body(self):
        return json.loads(self.body)


class DummyContext:
    def __init__(self, return_schema=None):
        self.return_schema = return_schema


@pytest.fixture
def dummy_request_context(params):
    return DummyContext(**(params.get("context", {})))


@pytest.fixture
def dummy_request(params: Mapping[str, Any], dummy_request_context):
    req = DummyRequest(**params.get("request", {}))
    req.context = dummy_request_context
    return req


@pytest.fixture
def localizer(params: Mapping[str, Any]):
    return Localizer(params["translations"])


@pytest.fixture
def dummy_configurator():
    config = setUp()
    yield config
    tearDown()
