"""Helpers / common code used for tests using SQLAlchemy models"""


from sqlalchemy import Column, ForeignKey, Integer, String
from sqlalchemy.orm import relationship

from sequoia.base3.helpers.sqla import (
    UUID,
    Database,
    SessionFactory,
    create_engine,
    dispose_engine,
)

SETTINGS = {
    "sql.testdb.url": "sqlite://",
    "sql.testdb.echo": False,
}
Base = Database.register("testdb")
SessionFactory.register("testdb")


class Dummy(Base):
    id = Column(Integer, primary_key=True)
    name = Column(String)
    uuid = Column(UUID)
    uuid_ng = Column(UUID(as_uuid=True))

    @property
    def lname(self):
        return self.name.lower()

    def failed(self):
        raise RuntimeError("Don't call me")

    @property
    def type(self):
        return "minion"


class MiniDummy(Base):
    id = Column(Integer, primary_key=True)
    name = Column(String)

    dummy_id = Column(Dummy.id.type, ForeignKey(Dummy.id, ondelete="cascade"))
    dummy = relationship(Dummy, backref="minis")


class AddOnDummy(Base):
    id = Column(Integer, primary_key=True)
    name = Column(String)

    dummy_id = Column(Dummy.id.type, ForeignKey(Dummy.id, ondelete="cascade"))
    dummy = relationship(Dummy, backref="addons")

    @property
    def failed(self):
        raise RuntimeError("Don't call me")


class TestCommon(object):
    """Common setup for engine / tables / session"""

    def setUp(self):
        self.engine = create_engine("testdb", SETTINGS)
        self.session = SessionFactory.get("testdb")
        Base.metadata.create_all(self.engine)

    def tearDown(self):
        self.session.close()
        Base.metadata.drop_all(self.engine)
        dispose_engine("testdb")
