"""
Test that fixtures are loading
"""

from unittest import TestCase

from sequoia.base3.testing.fixtures import FixtureTableJSon

from .sqlalchemy import Dummy, MiniDummy, TestCommon


class DummyFixture(FixtureTableJSon):
    model = Dummy
    database = "testdb"


class MiniDummyFixture(FixtureTableJSon):
    model = MiniDummy
    database = "testdb"


class TestFixtures(TestCommon, TestCase):
    def test_load_yaml_ok(self):
        fixture = DummyFixture()

        dummy_count = self.session.query(Dummy).count()
        self.assertEqual(dummy_count, 0)

        fixture.setUp()
        dummy_count = self.session.query(Dummy).count()
        self.assertEqual(dummy_count, 2)

        dummies = self.session.query(Dummy).filter(Dummy.name == "foo")
        self.assertEqual(dummies[0].id, 12)

        fixture.tearDown()

        dummy_count = self.session.query(Dummy).count()
        self.assertEqual(dummy_count, 0)

    def test_load_yaml_yaml_ok(self):
        # Test that loading a fixture from "xx/yaml/table.yaml" path works
        fixture = MiniDummyFixture()

        count = self.session.query(MiniDummy).count()
        self.assertEqual(count, 0)

        fixture.setUp()
        count = self.session.query(MiniDummy).count()
        self.assertEqual(count, 1)

        mini = self.session.query(MiniDummy).one()

        self.assertEqual(mini.name, "Billy")
        fixture.tearDown()

        count = self.session.query(MiniDummy).count()
        self.assertEqual(count, 0)
