# coding: utf-8

from unittest import TestCase

from pyramid.testing import DummyRequest
from webob.request import Request

from sequoia.base3.helpers import i18n


class I18NTestCase(TestCase):
    def test_locale_negociator_fr(self):
        request = Request.blank("/", headers={"Accept-Language": "fr"})
        self.assertEqual(i18n.locale_negotiator(request), "fr")
        request = Request.blank("/", headers={"Accept-Language": "fr-BE"})
        self.assertEqual(i18n.locale_negotiator(request), "fr")
        request = Request.blank("/", headers={"Accept-Language": "fr-be"})
        self.assertEqual(i18n.locale_negotiator(request), "fr")

    def test_locale_negociator_zh_hans(self):
        request = Request.blank("/", headers={"Accept-Language": "zh-hans"})
        self.assertEqual(i18n.locale_negotiator(request), "zh_CN")
        request = Request.blank("/", headers={"Accept-Language": "zh-CN"})
        self.assertEqual(i18n.locale_negotiator(request), "zh_CN")
        # _ does not work in accept languages
        # request = Request.blank('/', headers={'Accept-Language': 'zh_CN'})
        # self.assertEqual(i18n.locale_negotiator(request), 'zh_CN')
        request = Request.blank("/", headers={"Accept-Language": "zh-cn"})
        self.assertEqual(i18n.locale_negotiator(request), "zh_CN")

        # Fallback to zh_CN in case of unknown variant
        request = Request.blank("/", headers={"Accept-Language": "zh-unknown"})
        self.assertEqual(i18n.locale_negotiator(request), "zh_CN")

    def test_locale_negociator_zh_hant(self):
        request = Request.blank("/", headers={"Accept-Language": "zh-hant"})
        self.assertEqual(i18n.locale_negotiator(request), "zh_TW")
        request = Request.blank("/", headers={"Accept-Language": "zh-TW"})
        self.assertEqual(i18n.locale_negotiator(request), "zh_TW")
        # _ does not work in accept languages
        # request = Request.blank('/', headers={'Accept-Language': 'zh_TW'})
        # self.assertEqual(i18n.locale_negotiator(request), 'zh_TW')
        request = Request.blank("/", headers={"Accept-Language": "zh-tw"})
        self.assertEqual(i18n.locale_negotiator(request), "zh_TW")
        request = Request.blank("/", headers={"Accept-Language": "zh-hk"})
        self.assertEqual(i18n.locale_negotiator(request), "zh_TW")

    def test_locale_negociator_de(self):
        request = Request.blank("/", headers={"Accept-Language": "de"})
        self.assertEqual(i18n.locale_negotiator(request), "en")

    def test_locale_negociator_quality(self):
        request = Request.blank(
            "/", headers={"Accept-Language": "da, es;q=0.8, en;q=0.7"}
        )
        self.assertEqual(i18n.locale_negotiator(request), "es")

    def test_content_language_fr(self):
        request = DummyRequest(locale_name="fr")
        i18n.content_language(request)
        self.assertEqual(request.response.content_language, ("fr",))

    def test_content_language_zn_hans(self):
        request = DummyRequest(locale_name="zh_CN")
        i18n.content_language(request)
        self.assertEqual(request.response.content_language, ("zh-hans",))

    def test_content_language_zn_hant(self):
        request = DummyRequest(locale_name="zh_TW")
        i18n.content_language(request)
        self.assertEqual(request.response.content_language, ("zh-hant",))
