from unittest import TestCase

import colander
from pyramid.testing import DummyRequest

from ...helpers.colander import missing_country


class MissingCountry(colander.MappingSchema):
    country = colander.SchemaNode(colander.String(), missing=missing_country)


class TestMissingCountry(TestCase):
    def test_post_missing_country(self):
        bound = MissingCountry().bind(request=DummyRequest())
        res = bound.deserialize({})
        self.assertNotIn("country", res)

    def test_post_country_in_request(self):
        request = DummyRequest(headers={"X-Country-Code": "FR"})
        bound = MissingCountry().bind(request=request)
        res = bound.deserialize({})
        self.assertIn("country", res)
        self.assertEqual(res["country"], "FR")

    def test_post_country_in_body(self):
        bound = MissingCountry().bind(request=DummyRequest())
        res = bound.deserialize({"country": "FR"})
        self.assertIn("country", res)
        self.assertEqual(res["country"], "FR")

        request = DummyRequest(headers={"X-Country-Code": "XX"})
        bound = MissingCountry().bind(request=request)
        res = bound.deserialize({"country": "FR"})
        self.assertIn("country", res)
        self.assertEqual(res["country"], "FR")
