import os
from unittest import TestCase, mock

from ...helpers.settings import patch_settings_from_env


class TestSettings(TestCase):
    @mock.patch.dict(
        os.environ,
        {
            "SEQUOIA_env": "env",
            "SEQUOIA_nested__env": "nested-env",
            "NOT_SEQUOIA_env": "env",
        },
    )
    def test_settings(self):
        settings = {}
        patch_settings_from_env(settings)
        assert settings == {
            "env": "env",
            "nested.env": "nested-env",
        }

    @mock.patch.dict(
        os.environ,
        {
            "SEQUOIA_env": "env",
            "SEQUOIA_integer": "12345",
            "SEQUOIA_float": "1337.42",
            "SEQUOIA_dict": '{"test": "it\'s fine"}',
            "SEQUOIA_list": '[1, 2, 3, "ok"]',
        },
    )
    def test_settings_types(self):
        settings = {}
        patch_settings_from_env(settings)
        assert settings == {
            "env": "env",
            "integer": 12345,
            "float": 1337.42,
            "dict": {"test": "it's fine"},
            "list": [1, 2, 3, "ok"],
        }
