"""Main entry point
"""
import logging
import sys

from pyramid.config import Configurator
from pyramid.exceptions import ConfigurationError
from pyramid.interfaces import IRoutesMapper
from pyramid.settings import aslist
from pyramid.tweens import INGRESS

from .config import export_api, includeme
from .helpers.i18n import locale_negotiator
from .helpers.pyramid import HateoasRoutesMapper, request_factory
from .helpers.renderer import JsonRenderer
from .helpers.settings import patch_settings_from_env

log = logging.getLogger(__name__)


def main(global_config, **settings):
    patch_settings_from_env(settings)
    includes = aslist(settings.pop("pyramid.includes", ""), flatten=False)
    config = Configurator(
        settings=settings,
        root_factory="sequoia.base3.context.DefaultContext",
        locale_negotiator=locale_negotiator,
        request_factory=request_factory,
    )
    # override json renderer to accept datetime to cast in string
    config.add_renderer("json", JsonRenderer)

    config.add_tween("sequoia.base3.helpers.pyramid.http_cache_factory", under=INGRESS)
    # override the route mapper
    config.registry.registerUtility(HateoasRoutesMapper(), IRoutesMapper)

    config.include(includeme)

    for conf in includes:
        if conf == "sequoia.base3":
            log.warning(
                "Ignoring sequoia.base3 from `pyramid.includes` " "you should remove it"
            )
            continue
        try:
            config.include(conf)
        except ConfigurationError:
            log.exception(
                "An error occurred when trying " "to configure: {}".format(conf)
            )
            sys.exit(1)
    config.include(export_api, route_prefix=settings.get("sequoia.route_prefix"))

    # push it back for the monitoring view
    config.registry.settings["pyramid.includes"] = includes
    return config.make_wsgi_app()
